SpringBoot的web应用一般都使用spring-boot-maven-plugin插件打包。打出的jar包内置了所有的依赖jar, 放在BOOT-INF/lib目录

~~~xml
<build>
    <plugins>
        <!-- 分离项目依赖的3rd包，写入target/dependency下-->
        <!-- 执行mvn dependency:copy-dependencies 或者IDEA Maven插件里找 -->
        <plugin>
            <groupId>org.apache.maven.plugins</groupId>
            <artifactId>maven-dependency-plugin</artifactId>
        </plugin>
        
        <!--springboot application 打包-->
        <plugin>
            <groupId>org.springframework.boot</groupId>
            <artifactId>spring-boot-maven-plugin</artifactId>
            <configuration>
                <fork>true</fork> <!-- 如果没有该配置，devtools不会生效 -->
                <layout>ZIP</layout>
                <includes> <!-- 只包含自己 -->
					<include>
						<groupId>${project.groupId}</groupId>
						<artifactId>${project.artifactId}</artifactId>
					</include>
				</includes>
            </configuration>
        </plugin>
    </plugins>
    
    <!-- 配置文件同样可以排除 -->
    <resources>
        <resource>
            <filtering>true</filtering>
            <directory>src/main/resources</directory>
            <excludes>
                <exclude>static/**</exclude>
                <exclude>templates/**</exclude>
                <exclude>*.yml</exclude>
                <exclude>*.properties</exclude>
                <exclude>*.xml</exclude>
                <exclude>*.txt</exclude>
            </excludes>
        </resource>
    </resources>
</build>
~~~

启动：

~~~bash
- dependency     # 都是3rd的依赖包
- application.yml
- ruoyi-2.3.0.jar

$ java -jar -Dloader.path=dependency ruoyi-2.3.0.jar
# loader.path指向外置目录,告诉springboot从外部加载依赖包，多个逗号分-Dloader.path=.,dependency
# 见https://docs.spring.io/spring-boot/docs/current/reference/html/appendix-executable-jar-format.html#executable-jar-launching
~~~

