# 使用patch-package修改Node.js依赖包内容

~~~bash
$ npm install patch-package --save-dev
~~~

修改依赖包源码后，创建patch文件

~~~bash
$ npx patch-package package-name   # 使用npm 创建patch
~~~

运行后会在项目根生产`patches`文件夹，补丁文件：`viewer+2.0.1.patch`

package.json中添加

~~~json
"scripts": {
  "postinstall": "patch-package"
}
~~~

后续运行`npm install`时，便会自动为依赖包打上我们的补丁。

# redis

日志一直有“Could not create server TCP listening socket *:6379: bind: Address already in use”

~~~bash
# 查看端口占用
$ sudo netstat -tunlp |grep 6379
tcp   0 0.0.0.0:6379  0.0.0.0:*     LISTEN      5601/redis-server * 
tcp6  0 :::6379       :::*          LISTEN      5601/redis-server * 
# 查看文件打开数
$ lsof -i:6379
COMMAND    PID  USER   FD   TYPE   NODE NAME
java      1044 kejia   20u  IPv6   TCP localhost:43828->localhost:6379 (ESTABLISHED)
redis-ser 5601 kejia    6u  IPv6   TCP *:6379 (LISTEN)
redis-ser 5601 kejia    7u  IPv4   TCP *:6379 (LISTEN)
redis-ser 5601 kejia    8u  IPv4   TCP localhost:6379->localhost:43828 (ESTABLISHED)
redis-ser 5601 kejia    9u  IPv4   TCP bogon:6379->bogon:50780 (ESTABLISHED)
redis-ser 5601 kejia   10u  IPv4   TCP bogon:6379->bogon:55694 (ESTABLISHED)
redis-ser 5601 kejia   11u  IPv4   TCP bogon:6379->bogon:49639 (ESTABLISHED)
redis-ser 5601 kejia   12u  IPv4   TCP bogon:6379->bogon:55162 (ESTABLISHED)
~~~

redis会创建ipv4和ipv6的socket，同时**监听**6379的ipv4和ipv6报文，提示“bind: Address already in use”。
原因：ipv6的socket默认情况下也会接收ipv4地址的报文，不同的socket不能监听同样的ip同样的端口。

查看redis.conf

bind的ip默认是 bind 127.0.0.1 ::1（::1表示ipv6的回环地址，相当于IPV4的127.0.0.1）

改成

bind 127.0.0.1

# Postfix Completion

高频使用的 代码模板 进行梳理

| 模板key | 描述                                                         | 用例            |
| ------- | ------------------------------------------------------------ | --------------- |
| var     | 快速定义局部变量，自带IDE类型推断                            | "yes".var       |
| nn      | 快速对变量判断not null                                       | name.nn         |
| if      | 快速if 判断                                                  | name.if         |
| for     | 迭代                                                         | list.for        |
| fori    | 带索引值迭代；同时对整型数字也支持                           | 18.fori         |
| try     | 快速对当前语句添加 try catch，同时 IDE 还会对Exception自动做类型推断 | conn.close;.try |
| cast    | 快速类型强转，配合instanceof使用时还能自动实现cast类型的推断： | list.castvar    |
| sys     | 自定义的System.out.println();                                | sys             |
| clog    | js的console.log()                                            | clog            |
| format  | 快速实现字符串格式化                                         | "%s".format     |
|         |                                                              |                 |
|         |                                                              |                 |
|         |                                                              |                 |
|         |                                                              |                 |

# Live Template

跟 Postfix 功能很相像，但灵活度更高

比如输入main，会自动补全一段函数

# 列编辑

鼠标中键

# 剪贴板

非常好用，`Ctrl+Shift+v`

对象的工具类：Objects   Objects.nonNull

把所有的for写成stream；
把所有可能获取失败的函数都返回Optional；

# Vue3

## provide & inject

可以实现嵌套组件间的数据传递。只能在 `setup()` 中使用。

父组件使用 `provide()` 向下传数据；子组件使用 `inject()` 获取上层传过来的数据

Parent.vue

~~~vue
<template>
  <div id="app">
    <Helloworld />
  </div>
</template>

<script>
    import { provide } from '@vue/composition-api'
    export default {
      setup() {
        const themeColor = ref('red') //themeColor改变，子组件的值自动更新
      	provide('global_color', themeColor) // 向子级组件共享数据（不限层级）
      },
      components: {
        Helloworld
      }
    }
</script>
~~~

~~~vue
<template>
    <h3 :style="{color: themeColor}">Level</h3>
</template>

<script>
    import { inject } from '@vue/composition-api'

    export default {
      setup() {
        const themeColor = inject('global_color') // 获取父级共享的数据
        return {
          themeColor
        }
      }
    }
</script>
~~~

